##  Link IT Components to the Reference Catalog
Provision the reference catalog from the Admin settings and link catalog items to your IT component fact sheets. The reference catalog automatically updates lifecycle status, version, support type, support status information, and more. SAP LeanIX Technology Risk and Compliance automatically retrieves vendor-provided lifecycle and end-of-support information and updates them in dedicated vendor lifecycle fields. This simplifies end-of-life asset management and brings clarity in making informed decisions about upgrades, transformations, or replacements. For more information, see [IT Components in the Reference Catalog](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for IT component fact sheets, you can increase standardization and data quality, set relations to other fact sheets for best-practice modeling, as well as manage technology obsolescence risks by using vendor lifecycle information.").
**Tip**
You can use the internal lifecycle field to retire an application earlier than the vendor's end-of-support date to align with your organization's specific operational requirements. This ensures a proactive transition rather than relying on vendor timelines.
You can also automate the process of setting an early internal end-of-life based on the vendor's end-of-life value. To learn about automation, see [Automations](https://help.sap.com/docs/leanix/ea/automations?locale=en-US&state=PRODUCTION&version=CLOUD "Configure no-code automations to streamline your workflows.").
![Linking IT Component Fact Sheets to Catalog Items](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e3e5f7a441014a71fc9aa6c2dc664_LowRes.png)
Linking IT Component Fact Sheets to Catalog Items
Start by linking the IT components where our recommendation engine has found matches with very high or high confidence based on name comparison. Use the confidence level filter in the bulk linking functionality of the catalog to narrow down the list.
![Confidence Level Filter in the Catalog Bulk Linking Functionality](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2743dff17a441014a46a924c8877f9c8_LowRes.png)
Confidence Level Filter in the Catalog Bulk Linking Functionality
**Note**
You can raise data requests in-tool if you need information about an IT component that is not already included in the reference catalog. For more detail, see [Report Missing Data in Catalog Items](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD#loio275adf737a44101482dccd5ff2ab307e__report_missing_data_in_catalog_items).
